#!/usr/bin/env python3
# Copyright (C) 2019, Miklos Maroti
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from setuptools import setup
from setuptools.command.build_py import build_py
import subprocess


class BuildPy(build_py):
    def run(self):
        subprocess.check_call(['make', 'all'], cwd='bin')
        build_py.run(self)


setup(
    name='provers',
    packages=['provers'],
    license='GPL 3',
    url="https://github.com/mmaroti/provers",
    author="Miklos Maroti",
    author_email="mmaroti@gmail.com",
    description="Library to access different different theorem provers",
    long_description=open('README.md').read(),
    python_requires='>=3.5',
    use_scm_version=True,
    setup_requires=[
        'setuptools_scm',
    ],
    install_requires=[
    ],
    entry_points={
        'console_scripts': [
            'provers = provers.__main__:run',
        ]
    },
    cmdclass={
        'build_py': BuildPy,
    },
)
